==> nextcloud-app-spreed-4.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/hu.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "SSL tanúsítvány érvényesítése",
    "Delete server" : "Szerver törlése",
    "Add new server" : "Szerver hozzáadása",
    "Saved" : "Elmentve",
    "Shared secret" : "Megosztott titok",
    "TURN server shared secret" : "TURN szerver megosztott titok",
    "TURN server protocols" : "TURN kiszolgáló protokollok",
    "UDP and TCP" : "UDP és TCP",
    "UDP only" : "csak UDP",
    "TCP only" : "csak TCP",
    "Screensharing is not supported by your browser." : "A böngésződ nem támogatja a képernyőmegosztást.",
    "Screensharing requires the page to be loaded through HTTPS." : "A képernyőmegosztáshoz HTTPS szükséges.",
    "Screensharing options" : "Képernyő megosztás beállításai",
    "Sharing your screen only works with Firefox version 52 or newer." : "A képernyőmegosztás 52-es és magasabb Firefox verziótól érhető el.",
    "Screensharing extension is required to share your screen." : "Képernyőmegosztó bővítményre van szükség.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Kérjük használj más böngészőt, például Firefox-ot vagy Chrome-ot, a képernyőmegosztáshoz.",
    "An error occurred while starting screensharing." : "Hiba lépett fel a képernyőmegosztás közben.",
    "Participants" : "Résztvevők",
    "Chat" : "Csevegés",
    "Talk" : "Beszélgetés",
    "Waiting for {participantName} to join the call …" : "Várakozunk, hogy {participantName} csatlakozzon a híváshoz...",
    "Waiting for others to join the call …" : "Várakozunk, hogy mások csatlakozzanak a híváshoz...",
    "No Camera" : "Nincs kamera",
    "Enable screensharing" : "Képernyő megosztás engedélyezése",
    "Copy" : "Másol",
    "Copied!" : "Másolva!",
    "Not supported!" : "Nem támogatott!",
    "Press ⌘-C to copy." : "Nyomj ⌘-C-t a másoláshoz.",
    "Press Ctrl-C to copy." : "Nyomj Ctrl-C-t a másoláshoz.",
    "Share screen" : "Képernyő megosztása",
    "Show your screen" : "Képernyőd megosztása",
    "Stop screensharing" : "Képernyő megosztás befejezése",
    "Please enter the password for this call" : "Kérlek adj meg egy jelszót ehhez a híváshoz",
    "Password required" : "Jelszó szükséges",
    "Password" : "Jelszó",
    "Cancel" : "Mégse",
    "Submit" : "Küldés",
    "Leave call" : "Hívás elhagyása",
    "Join call" : "Csatlakozás híváshoz",
    "Share link" : "Megosztás hivatkozással",
    "Change password" : "Jelszó módosítása",
    "Set password" : "Jelszó beállítása",
    "Name" : "Név",
    "Rename" : "Átnevez",
    "Copy link" : "Hivatkozás másolása",
    "Conversation with {name}" : "Beszélgetés vele: {name}",
    "Error occurred while setting password" : "Hiba a jelszó beállításakor",
    "Link copied!" : "Hivatkozás másolva!",
    "You" : "Te",
    "No messages yet, start the conversation!" : "Még nincs üzenet, kezdeményezz beszélgetést!",
    "Send" : "Küld",
    "Guest" : "Vendég",
    "[Unknown user name]" : "[ismeretlen felhasználónév]",
    "Today" : "Ma",
    "Yesterday" : "Tegnap",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "Hiba az üzenetküldés közben",
    "Edit" : "Szerkesztés",
    "moderator" : "moderátor",
    "Demote from moderator" : "lefokozás moderátorról",
    "Promote to moderator" : "Moderátorrá kinevezés",
    "Remove participant" : "Résztvevő eltávolítása",
    "No other people in this call" : "Nincs más ebben a hívásban",
    "You can invite others in the participant tab of the sidebar" : "Az oldalsávon található „közreműködő” fülön lehet másokat meghívni",
    "Share this link to invite others!" : "Oszd meg ezt a linket mások meghívásához!",
    "Close" : "Bezár",
    "Waiting for camera and microphone permissions" : "Várakozás kamera és mikrofon engedélyezésre",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Kérlek engedélyezd a kamera és mikrofon elérést az app használatához.",
    "Disable video" : "Videó kikapcsolása",
    "Show screen" : "Képernyőd mutatása",
    "Access to microphone & camera is only possible with HTTPS" : "A mikrofon és a kamera hozzáférése csak HTTPS-en lehetséges",
    "Access to microphone & camera was denied" : "A kamera és a mikrofon hozzáférése letiltva",
    "WebRTC is not supported in your browser" : "A böngésződ nem támogatja a WebRTC-t",
    "Please use a different browser like Firefox or Chrome" : "Kérlek használj másik böngészőt pl Firefoxot vagy Chrome-ot",
    "Error while accessing microphone & camera" : "Hiba a kamera és a mikrofon hozzáférésekor",
    "WebRTC is not supported in your browser :-/" : "A böngésződ nem támogatja a WebRTC-t :-/",
    "{participantName}'s screen" : "{participantName} képernyője",
    "Guest's screen" : "Vendég képernyője",
    "Your screen" : "Te képernyőd",
    "(Duration %s)" : "(Időtartam: %s)",
    "You attended a call with {user1}" : "Részt vettél egy hívásban vele: {user1}",
    "_%n guest_::_%n guests_" : ["%n vendég","%n vendég"],
    "You attended a call with {user1} and {user2}" : "Részt vettél egy hívásban velük: {user1}, {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Részt vettél egy hívásban velük: {user1}, {user2}, {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Részt vettél egy hívásban velük: {user1}, {user2}, {user3}, {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Részt vettél egy hívásban velük: {user1}, {user2}, {user3}, {user4}, {user5}",
    "_%n other_::_%n others_" : ["még %n","még %n"],
    "{actor} invited you to {call}" : "{actor} meghívott ide: {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Meghívtak egy <strong>beszélgető </strong> szobába vagy volt egy <strong>hívásod</strong>",
    "Talk to %s" : "Beszélgetés vele: %s",
    "_%n other guest_::_%n other guests_" : ["%n további vendég","%n további vendég"],
    ", " : ", ",
    "{user} wants to talk with you" : "{user} beszélni szeretne veled",
    "A group call has started in {call}" : "Csoportos hívás kezdődött itt: {call}",
    "A group call has started" : "Csoportos hívás kezdődött",
    "This call is password-protected" : "Ez a hívás jelszóval védett",
    "The password is wrong. Try again." : "Hibás jelszó, próbáld újra.",
    "Signaling server" : "Jelző szerver",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Külső jelzőszerver használata is lehetséges nagyobb telepítések esetén. Hagyd üresen a belső szerver használatához.",
    "STUN servers" : "STUN szerverek",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Egy STUN szervert használunk a router mögötti résztvevők IP címének megállapítására.",
    "TURN server" : "TURN kiszolgáló",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "A TURN szervert használjuk a proxyként a tűzfal mögötti felhasználókhoz.",
    "Video calls" : "Videó hívások",
    "(group)" : "(csoport)",
    "New public call" : "Új nyilvános hívás",
    "Looking great today! :)" : "Jól nézel ki ma! :)",
    "Time to call your friends" : "Ideje a barátaidat felhívni",
    "You can set your name on the top right of this page so other participants can identify you better." : "A jelenlegi oldal jobb felső sarkában állíthatod be a neved a könnyebb azonosíthatóság érdekében.",
    "This call has ended" : "A hívás véget ért",
    "Saving failed" : "Mentés sikertelen",
    "Add person" : "Személy hozzáadás",
    "and you" : "és te",
    "Please adjust your configuration" : "Kérlek állíts a konfiguráción",
    "{actor} invited you to a private call" : "{actor} meghívott egy privát beszélgetésbe",
    "{actor} invited you to a group call" : "{actor} meghívott egy csoportos beszélgetésbe",
    "{actor} invited you to the call {call}" : "{actor} meghívott a(z) {call} beszélgetésbe",
    "You were invited to a <strong>video call</strong>" : "Meghívtak egy <strong>videó hívásba</strong>",
    "Video call" : "Videóhívás",
    "Invalid format, must be stunserver:port." : "Érvénytelen formátum, ilyennek kell lennie: stunserver:port.",
    "Invalid port specified." : "A megadott port érvénytelen",
    "Invalid protocols specified." : "A megadott protokollok nem érvényesek.",
    "%s invited you to a private call" : "%s meghívott egy privát beszélgetésre",
    "{user} invited you to a private call" : "{user} meghívott egy privát beszélgetésre",
    "%s invited you to a group call: %s" : "%s meghívott egy csoportos hívásba: %s",
    "{user} invited you to a group call: {call}" : "{user} meghívott egy csoportos hívásba: {call}",
    "%s invited you to a group call" : "%s meghívott egy csoportos beszélgetésre",
    "{user} invited you to a group call" : "{user} meghívott egy csoportos beszélgetésre",
    "Fullscreen" : "Teljes képernyő",
    "Mute audio" : "Hang némítása",
    "Smile in 3… 2… 1!" : "3… 2… 1... mosolyogj!",
    "Choose person …" : "Válassz valakit ...",
    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "A STUN szerver azért szükséges, hogy mások is csatlakozhassanak a beszélgetésekhez. A TURN szerver a tűzfal mögötti felhasználók csatlakozását biztosítja.",
    "STUN server" : "STUN kiszolgáló",
    "The STUN server is used to determine the public IP address of participants behind a router." : "A STUN szervert használunk a router mögötti résztvevők publikus IP címének megállapítására.",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-4.0.1-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/hu.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "SSL tanúsítvány érvényesítése",
    "Delete server" : "Szerver törlése",
    "Add new server" : "Szerver hozzáadása",
    "Saved" : "Elmentve",
    "Shared secret" : "Megosztott titok",
    "TURN server shared secret" : "TURN szerver megosztott titok",
    "UDP and TCP" : "UDP és TCP",
    "UDP only" : "csak UDP",
    "TCP only" : "csak TCP",
    "TURN server protocols" : "TURN kiszolgáló protokollok",
    "New public conversation" : "Új nyilvános beszélgetés",
    "New conversation …" : "Új beszélgetés …",
    "Screensharing is not supported by your browser." : "A böngésződ nem támogatja a képernyőmegosztást.",
    "Screensharing requires the page to be loaded through HTTPS." : "A képernyőmegosztáshoz HTTPS szükséges.",
    "Screensharing options" : "Képernyő megosztás beállításai",
    "Sharing your screen only works with Firefox version 52 or newer." : "A képernyőmegosztás 52-es és magasabb Firefox verziótól érhető el.",
    "Screensharing extension is required to share your screen." : "Képernyőmegosztó bővítményre van szükség.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Kérjük használj más böngészőt, például Firefox-ot vagy Chrome-ot, a képernyőmegosztáshoz.",
    "An error occurred while starting screensharing." : "Hiba lépett fel a képernyőmegosztás közben.",
    "Participants" : "Résztvevők",
    "Chat" : "Csevegés",
    "Talk" : "Beszélgetés",
    "Waiting for {participantName} to join the call …" : "Várakozunk, hogy {participantName} csatlakozzon a híváshoz...",
    "Waiting for others to join the call …" : "Várakozunk, hogy mások csatlakozzanak a híváshoz...",
    "Exit fullscreen (f)" : "Kilépés a teljes képernyős módból (f)",
    "Mute audio (m)" : "Audio elnémítása (m)",
    "No Camera" : "Nincs kamera",
    "Enable screensharing" : "Képernyő megosztás engedélyezése",
    "Copy" : "Másol",
    "Copied!" : "Másolva!",
    "Not supported!" : "Nem támogatott!",
    "Press ⌘-C to copy." : "Nyomj ⌘-C-t a másoláshoz.",
    "Press Ctrl-C to copy." : "Nyomj Ctrl-C-t a másoláshoz.",
    "Share screen" : "Képernyő megosztása",
    "Show your screen" : "Képernyőd megosztása",
    "Stop screensharing" : "Képernyő megosztás befejezése",
    "Please enter the password for this call" : "Kérlek adj meg egy jelszót ehhez a híváshoz",
    "Password required" : "Jelszó szükséges",
    "Password" : "Jelszó",
    "Cancel" : "Mégse",
    "Submit" : "Küldés",
    "Leave call" : "Hívás elhagyása",
    "Join call" : "Csatlakozás híváshoz",
    "Share link" : "Megosztás hivatkozással",
    "Change password" : "Jelszó módosítása",
    "Set password" : "Jelszó beállítása",
    "Name" : "Név",
    "Rename" : "Átnevezés",
    "Copy link" : "Hivatkozás másolása",
    "Conversation with {name}" : "Beszélgetés vele: {name}",
    "Error occurred while setting password" : "Hiba a jelszó beállításakor",
    "Link copied!" : "Hivatkozás másolva!",
    "You" : "Te",
    "No messages yet, start the conversation!" : "Még nincs üzenet, kezdeményezz beszélgetést!",
    "Send" : "Küld",
    "Guest" : "Vendég",
    "[Unknown user name]" : "[ismeretlen felhasználónév]",
    "Today" : "Ma",
    "Yesterday" : "Tegnap",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "Hiba az üzenetküldés közben",
    "Edit" : "Szerkesztés",
    "moderator" : "moderátor",
    "Demote from moderator" : "lefokozás moderátorról",
    "Promote to moderator" : "Moderátorrá kinevezés",
    "Remove participant" : "Résztvevő eltávolítása",
    "Delete conversation" : "Beszélgetés törlése",
    "No other people in this call" : "Nincs más ebben a hívásban",
    "You can invite others in the participant tab of the sidebar" : "Az oldalsávon található „közreműködő” fülön lehet másokat meghívni",
    "Share this link to invite others!" : "Oszd meg ezt a linket mások meghívásához!",
    "Close" : "Bezár",
    "Waiting for camera and microphone permissions" : "Várakozás kamera és mikrofon engedélyezésre",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Kérlek engedélyezd a kamera és mikrofon elérést az app használatához.",
    "Disable video" : "Videó kikapcsolása",
    "Show screen" : "Képernyőd mutatása",
    "Access to microphone & camera is only possible with HTTPS" : "A mikrofon és a kamera hozzáférése csak HTTPS-en lehetséges",
    "Access to microphone & camera was denied" : "A kamera és a mikrofon hozzáférése letiltva",
    "WebRTC is not supported in your browser" : "A böngésződ nem támogatja a WebRTC-t",
    "Please use a different browser like Firefox or Chrome" : "Kérlek használj másik böngészőt pl Firefoxot vagy Chrome-ot",
    "Error while accessing microphone & camera" : "Hiba a kamera és a mikrofon hozzáférésekor",
    "WebRTC is not supported in your browser :-/" : "A böngésződ nem támogatja a WebRTC-t :-/",
    "{participantName}'s screen" : "{participantName} képernyője",
    "Guest's screen" : "Vendég képernyője",
    "Your screen" : "Te képernyőd",
    "(Duration %s)" : "(Időtartam: %s)",
    "You attended a call with {user1}" : "Részt vettél egy hívásban vele: {user1}",
    "_%n guest_::_%n guests_" : ["%n vendég","%n vendég"],
    "You attended a call with {user1} and {user2}" : "Részt vettél egy hívásban velük: {user1}, {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Részt vettél egy hívásban velük: {user1}, {user2}, {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Részt vettél egy hívásban velük: {user1}, {user2}, {user3}, {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Részt vettél egy hívásban velük: {user1}, {user2}, {user3}, {user4}, {user5}",
    "_%n other_::_%n others_" : ["még %n","még %n"],
    "{actor} invited you to {call}" : "{actor} meghívott ide: {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Meghívtak egy <strong>beszélgető </strong> szobába vagy volt egy <strong>hívásod</strong>",
    "Talk to %s" : "Beszélgetés vele: %s",
    "_%n other guest_::_%n other guests_" : ["%n további vendég","%n további vendég"],
    ", " : ", ",
    "{user} wants to talk with you" : "{user} beszélni szeretne veled",
    "A group call has started in {call}" : "Csoportos hívás kezdődött itt: {call}",
    "A group call has started" : "Csoportos hívás kezdődött",
    "This call is password-protected" : "Ez a hívás jelszóval védett",
    "The password is wrong. Try again." : "Hibás jelszó, próbáld újra.",
    "Signaling server" : "Jelző szerver",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Külső jelzőszerver használata is lehetséges nagyobb telepítések esetén. Hagyd üresen a belső szerver használatához.",
    "STUN servers" : "STUN szerverek",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Egy STUN szervert használunk a router mögötti résztvevők IP címének megállapítására.",
    "TURN server" : "TURN kiszolgáló",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "A TURN szervert használjuk a proxyként a tűzfal mögötti felhasználókhoz.",
    "Video calls" : "Videó hívások",
    "(group)" : "(csoport)",
    "New public call" : "Új nyilvános hívás",
    "Looking great today! :)" : "Jól nézel ki ma! :)",
    "Time to call your friends" : "Ideje a barátaidat felhívni",
    "You can set your name on the top right of this page so other participants can identify you better." : "A jelenlegi oldal jobb felső sarkában állíthatod be a neved a könnyebb azonosíthatóság érdekében.",
    "This call has ended" : "A hívás véget ért",
    "Saving failed" : "Mentés sikertelen",
    "Add person" : "Személy hozzáadás",
    "and you" : "és te",
    "Please adjust your configuration" : "Kérlek állíts a konfiguráción",
    "{actor} invited you to a private call" : "{actor} meghívott egy privát beszélgetésbe",
    "{actor} invited you to a group call" : "{actor} meghívott egy csoportos beszélgetésbe",
    "{actor} invited you to the call {call}" : "{actor} meghívott a(z) {call} beszélgetésbe",
    "You were invited to a <strong>video call</strong>" : "Meghívtak egy <strong>videó hívásba</strong>",
    "Video call" : "Videóhívás",
    "Invalid format, must be stunserver:port." : "Érvénytelen formátum, ilyennek kell lennie: stunserver:port.",
    "Invalid port specified." : "A megadott port érvénytelen",
    "Invalid protocols specified." : "A megadott protokollok nem érvényesek.",
    "%s invited you to a private call" : "%s meghívott egy privát beszélgetésre",
    "{user} invited you to a private call" : "{user} meghívott egy privát beszélgetésre",
    "%s invited you to a group call: %s" : "%s meghívott egy csoportos hívásba: %s",
    "{user} invited you to a group call: {call}" : "{user} meghívott egy csoportos hívásba: {call}",
    "%s invited you to a group call" : "%s meghívott egy csoportos beszélgetésre",
    "{user} invited you to a group call" : "{user} meghívott egy csoportos beszélgetésre",
    "Fullscreen" : "Teljes képernyő",
    "Mute audio" : "Hang némítása",
    "Smile in 3… 2… 1!" : "3… 2… 1... mosolyogj!",
    "Choose person …" : "Válassz valakit ...",
    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "A STUN szerver azért szükséges, hogy mások is csatlakozhassanak a beszélgetésekhez. A TURN szerver a tűzfal mögötti felhasználók csatlakozását biztosítja.",
    "STUN server" : "STUN kiszolgáló",
    "The STUN server is used to determine the public IP address of participants behind a router." : "A STUN szervert használunk a router mögötti résztvevők publikus IP címének megállapítására.",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …",
    "%s mentioned you in a group conversation: %s" : "%s megemlített téged egy csoportos beszélgetésben: %s",
    "{user} mentioned you in a group conversation: {call}" : "{user} megemlített téged egy csoportos beszélgetésben: {call}",
    "%s mentioned you in a group conversation" : "%s megemlített téged egy csoportos beszélgetésben",
    "{user} mentioned you in a group conversation" : "{user} megemlített téged egy csoportos beszélgetésben",
    "A guest mentioned you in a group conversation: %s" : "Egy vendég megemlített téged egy csoportos beszélgetésben: %s",
    "A guest mentioned you in a group conversation: {call}" : "Egy vendég megemlített téged egy csoportos beszélgetésben: {call}",
    "A guest mentioned you in a group conversation" : "Egy vendég megemlített téged egy csoportos beszélgetésben"
},
"nplurals=2; plural=(n != 1);");
